@@ -1,6 +1,6 @@
 """
-Doc strings provide additional documentation on a certain function.
-They can be accessed by the built-in Python `help()` command.
+Docstrings provide additional documentation on a certain function.
+They can be accessed via the built-in Python `help()` command.
 These strings are formatted in Github-flavored markdown.
 Additionally, all files will have a 'STRUCTURE' label.
 """
@@ -20,6 +20,9 @@ from . import plots
 from . import fitters
 
 # version info
-__version__ = "v2.0.1.23"  # version (v#.#.#)
-__stable__ = True  # True --> stable release, False --> unstable release
+__version__ = "v2.1.1.1"  # version (v#.#.#)
+"""epispot's version info"""
+__stable__ = False
+"""stability of the build: True --> stable release (master), False --> unstable release (nightly)"""
 __repo_data_url__ = 'https://www.github.com/epispot/epispot'  # source repo
+"""URL to GitHub source"""
